@@ -9,17 +9,19 @@
 #define SIGCXX_MAJOR_VERSION 2
 
 /* Minor version number of sigc++. */
-#define SIGCXX_MINOR_VERSION 10
+#define SIGCXX_MINOR_VERSION 12
 
 /* Micro version number of sigc++. */
-#define SIGCXX_MICRO_VERSION 7
+#define SIGCXX_MICRO_VERSION 1
 
 /* Detect Win32 platform */
 #ifdef _WIN32
 # if defined(_MSC_VER)
 #  define SIGC_MSC 1
 #  define SIGC_WIN32 1
-#  define SIGC_DLL 1
+#  ifndef LIBSIGCXX_STATIC
+#   define SIGC_DLL 1
+#  endif
 # elif defined(__CYGWIN__)
 #  define SIGC_CONFIGURE 1
 # elif defined(__MINGW32__)
@@ -75,12 +77,10 @@
 #endif /* !SIGC_MSC */
 
 #ifdef SIGC_DLL
-# if defined(SIGC_BUILD) && defined(_WINDLL)
+# ifdef SIGC_BUILD
 #  define SIGC_API __declspec(dllexport)
-# elif !defined(SIGC_BUILD)
-#  define SIGC_API __declspec(dllimport)
 # else
-#  define SIGC_API
+#  define SIGC_API __declspec(dllimport)
 # endif
 #else /* !SIGC_DLL */
 # define SIGC_API
